@@ -78,6 +78,8 @@ class RoborockStateCode(RoborockEnum):
     mapping = 29
     egg_attack = 30
     patrol = 32
+    attaching_the_mop = 33  # on g20s ultra
+    detaching_the_mop = 34  # on g20s ultra
     charging_complete = 100
     device_offline = 101
     locked = 103
@@ -463,6 +465,7 @@ class RoborockDockTypeCode(RoborockEnum):
     qrevo_s_dock = 15
     saros_r10_dock = 16
     qrevo_curv_dock = 17
+    saros_10_dock = 18
 
 
 class RoborockDockDustCollectionModeCode(RoborockEnum):
